#
# spec file for package compiz-emerald
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _rev    64c02befbf3a2fee2e1a7ab266938f9a
%define _name   emerald
Name:           compiz-emerald
Version:        0.8.18
Release:        2.22
Summary:        Themeable window decorator for Compiz
License:        GPL-2.0-or-later
URL:            https://gitlab.com/compiz/emerald
Source:         https://gitlab.com/compiz/emerald/uploads/%{_rev}/%{_name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libdecoration) < 0.9
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(xrender) >= 0.8.4
Requires:       compiz < 0.9
Recommends:     %{name}-theme-manager >= %{version}
Recommends:     %{name}-themes
Provides:       compiz-decorator = 0.8

%description
Emerald is a themeable window decorator for Compiz.

%lang_package

%package theme-manager
Summary:        Graphical theme manager for Emerald
Requires:       %{name} >= %{version}

%description theme-manager
Emerald is a themeable window decorator for Compiz.

This package contains a graphical theme manager.

%package devel
Summary:        Development files for compiz-emerald
Requires:       %{name} = %{version}
Requires:       gcc-c++
Requires:       pkgconfig(gtk+-3.0)
Requires:       pkgconfig(libdecoration) < 0.9
Requires:       pkgconfig(libwnck-3.0)
Requires:       pkgconfig(pangocairo)
Requires:       pkgconfig(xrender) >= 0.8.4

%description devel
Emerald is a themeable window decorator for Compiz.

This package holds the development files for compiz-emerald.

%prep
%setup -q -n %{_name}-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --with-gtk=3.0        \
  --disable-static      \
  --disable-mime-update
%make_build

%install
%make_install
# /usr/share/mime-info was GNOME 1 infrastructure. These times are long gone
rm -rf %{buildroot}%{_datadir}/mime-info
%suse_update_desktop_file %{_name}-theme-manager DesktopSettings
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}/
%find_lang %{_name}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/%{_name}
%{_libdir}/%{_name}/
%{_libdir}/libemeraldengine.so.*
%{_datadir}/%{_name}/
%{_datadir}/icons/hicolor/*/mimetypes/*%{_name}*
%{_datadir}/mime/packages/%{_name}.xml
%{_mandir}/man1/%{_name}.1%{?ext_man}

%files lang -f %{_name}.lang

%files theme-manager
%{_bindir}/%{_name}-theme-manager
%{_datadir}/applications/*%{_name}*.desktop
%{_datadir}/icons/hicolor/*/apps/*%{_name}-theme-manager*
%{_mandir}/man1/%{_name}-theme-manager.1%{?ext_man}

%files devel
%{_includedir}/%{_name}/
%{_libdir}/libemeraldengine.so
%{_libdir}/pkgconfig/%{_name}*.pc

%changelog
* Fri Jun 26 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Do not package /usr/share/mime-info: this was from the times of
  GNOME 1 and is no longer used (boo#1062631).
* Sat Apr  4 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.8.18:
  * Add ability to configure window grab areas independently from
    borders.
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Drop support for old openSUSE versions.
* Sun Nov 11 2018 sor.alexei@meowr.ru
- Update to version 0.8.16:
  * Random fixes and updates.
- Remove emerald-0.8.14-fix-app-switchers.patch: fixed upstream.
* Wed May 10 2017 sor.alexei@meowr.ru
- Add emerald-0.8.14-fix-app-switchers.patch: Fix issues with
  application switchers (commit 27d4e0d).
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.8.14:
  * Fix wrong border extents.
  * Fix oversized buttons.
  * Fix crash when special characters are displayed in titlebar.
  * Fix various GTK+ problems.
  * Respect GTK+ double-click speed.
  * Allow configurable middle-click titlebar actions.
  * Update translations.
* Mon Apr  4 2016 sor.alexei@meowr.ru
- Update to 0.8.12.4:
  * Fix button glow glitches.
  * Remove possibility to select button glow for non-pixmap buttons
    (glow is only for pixmap buttons).
  * Fix theme being reselected when not asked on GTK+ 3.8+.
    Left unfixed in builds on older GTK+.
  * Fix button glow for only active or only inactive windows.
  * Fix broken appearance on HiDPI with GTK+ 3.10+ (if scaling is on).
    For now scaling is just disabled completely.
  * Other minor fixes.
- Split emerald-theme-manager into a separate package (add set as
  a recommendation of emerald).
* Thu Mar 17 2016 sor.alexei@meowr.ru
- Update to 0.8.12.3:
  * Probably fix "white glitches" that happen on resize.
  * Fix a X11 Drawable leakage.
* Wed Mar 16 2016 sor.alexei@meowr.ru
- Update to 0.8.12.2:
  * Fix having resize cursor activated for maximised windows.
  * Fix right click near top edge of maximised windows.
  * Add an option to emerald-theme-manager to disable shading when
    titlebar is scrolled.
  * Add support for a Super Maximise button (toggles fullscreen).
  * Fix some memory leaks.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to 0.8.12.1:
  * Fix a crash when Shift Switcher was enabled after Emerald and
    used.
  * Place emerald-theme-manager into /usr/share/icons/ and remove
    useless icons from there.
* Sat Feb 13 2016 sor.alexei@meowr.ru
- Update to 0.8.12:
  * Remove start scripts: no longer make sense.
  * Add Gtk3 support (by default).
  * Add additional Compiz 0.9.x support (configure --enable-decor09
    argument).
  * Fix resize glitches on some GPU's.
  * Fix wrong size of button tooltips when hovering from one to
    another.
* Sat Dec 19 2015 sor.alexei@meowr.ru
- Use a better upstream tarball.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.8.9.
- Split compiz-emerald-lang package.
- Remove gdk64bitportabilityissue.diff and 30-bit-shadow.patch:
  fixed upstream.
- Remove compiz-emerald-rpmlintrc: no use for it.
- Spec cleanup.
* Sat May 10 2014 ku.b@gmx.de
- support 30-bit visuals by skipping shadow painting
- fix License naming
- add changelog file
- move devel libs to devel package
* Thu Apr 28 2011 robertherb@arcor.de
- update to 0.8.8
